@@ -4,6 +4,7 @@
 # Description:  Darwin Core XMP tags
 #
 # Revisions:    2013-01-28 - P. Harvey Created
+#               2025-03-09 - Herb forum17172 changes dwc.tdwg.org 2023
 #
 # References:   1) http://rs.tdwg.org/dwc/index.htm
 #               2) https://exiftool.org/forum/index.php/topic,4442.0/all.html
@@ -15,7 +16,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool::XMP;
 
-$VERSION = '1.07';
+$VERSION = '1.08';
 
 my %dateTimeInfo = (
     # NOTE: Do NOT put "Groups" here because Groups hash must not be common!
@@ -35,7 +36,7 @@ my %event = (
     STRUCT_NAME => 'DarwinCore Event',
     NAMESPACE => 'dwc',
     day                 => { Writable => 'integer', Groups => { 2 => 'Time' } },
-    earliestDate        => { %dateTimeInfo, Groups => { 2 => 'Time' } },
+    earliestDate        => { %dateTimeInfo, Groups => { 2 => 'Time' } },     # dwc.tdwg.org removed 2023
     endDayOfYear        => { Writable => 'integer', Groups => { 2 => 'Time' } },
     eventDate           => { %dateTimeInfo, Groups => { 2 => 'Time' } },
     eventID             => { Avoid => 1, Notes => 'avoided in favor of XMP-iptcExt:EventID' },
@@ -63,7 +64,7 @@ my %event = (
     fieldNotes          => { },
     fieldNumber         => { },
     habitat             => { },
-    latestDate          => { %dateTimeInfo, Groups => { 2 => 'Time' } },
+    latestDate          => { %dateTimeInfo, Groups => { 2 => 'Time' } },      # dwc.tdwg.org removed 2023
     month               => { Writable => 'integer', Groups => { 2 => 'Time' } },
     parentEventID       => { },
     samplingEffort      => { },
@@ -73,6 +74,7 @@ my %event = (
     startDayOfYear      => { Writable => 'integer', Groups => { 2 => 'Time' } },
     verbatimEventDate   => { Groups => { 2 => 'Time' } },
     year                => { Writable => 'integer', Groups => { 2 => 'Time' } },
+    eventType           => { },                                               # dwc.tdwg.org added 2023
 );
 
 # Darwin Core tags
@@ -161,6 +163,7 @@ my %event = (
             measurementType             => { },
             measurementUnit             => { },
             measurementValue            => { },
+            parentMeasurementID         => { },          # dwc.tdwg.org added 2023
         },
     },
     Occurrence => {
@@ -170,25 +173,25 @@ my %event = (
             associatedMedia             => { },
             associatedOccurrences       => { },
             associatedReferences        => { },
-            associatedSequences         => { },
+            associatedSequences         => { },         # dwc.tdwg.org removed 2023
             associatedTaxa              => { },
             behavior                    => { },
             catalogNumber               => { },
-            disposition                 => { },
+            disposition                 => { },         # dwc.tdwg.org removed 2023
             establishmentMeans          => { },
             individualCount             => { },
-            individualID                => { },
+            individualID                => { },         # dwc.tdwg.org removed 2023
             lifeStage                   => { },
             occurrenceDetails           => { },
-            occurrenceID                => { },
+            occurrenceID                => { },         # dwc.tdwg.org removed 2023
             occurrenceRemarks           => { },
             occurrenceStatus            => { },
             organismQuantity            => { },
             organismQuantityType        => { },
             otherCatalogNumbers         => { },
             preparations                => { },
-            previousIdentifications     => { },
-            recordedBy                  => { },
+            previousIdentifications     => { },         # dwc.tdwg.org removed 2023
+            recordedBy                  => { },         # dwc.tdwg.org removed 2023
             recordNumber                => { },
             reproductiveCondition       => { },
             sex                         => { },
@@ -197,6 +200,8 @@ my %event = (
             georeferenceVerificationStatus => { },
             pathway                     => { },
             recordedByID                => { },
+            caste                       => { },         # dwc.tdwg.org added 2023
+            vitality                    => { },         # dwc.tdwg.org added 2023
         },
     },
     OccurrenceOccurrenceDetails => { Name => 'OccurrenceDetails', Flat => 1 },
@@ -207,7 +212,7 @@ my %event = (
         Struct => {
             STRUCT_NAME => 'DarwinCore Organism',
             NAMESPACE => 'dwc',
-            associatedOccurrences       => { },
+            associatedOccurrences       => { },          # dwc.tdwg.org removed 2023
             associatedOrganisms         => { },
             organismID                  => { },
             organismName                => { },
@@ -291,6 +296,12 @@ my %event = (
             taxonomicStatus             => { },
             verbatimTaxonRank           => { },
             vernacularName              => { Writable => 'lang-alt' },
+            superFamily                 => { },     # dwc.tdwg.org added 2023
+            subFamily                   => { },     # dwc.tdwg.org added 2023
+            tribe                       => { },     # dwc.tdwg.org added 2023
+            subTribe                    => { },     # dwc.tdwg.org added 2023
+            genericName                 => { },     # dwc.tdwg.org added 2023
+            infragenericEpithet         => { },     # dwc.tdwg.org added 2023
         },
     },
     TaxonTaxonConceptID => { Name => 'TaxonConceptID',  Flat => 1 },
@@ -321,7 +332,7 @@ my %event = (
             georeferenceProtocol        => { },
             georeferenceRemarks         => { },
             georeferenceSources         => { },
-            georeferenceVerificationStatus => { },
+            georeferenceVerificationStatus => { },      # dwc.tdwg.org removed 2023
             higherGeography             => { },
             higherGeographyID           => { },
             island                      => { },
