@@ -24,7 +24,7 @@ use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 use Image::ExifTool::GPS;
 
-$VERSION = '1.22';
+$VERSION = '1.23';
 
 sub ProcessFLIR($$;$);
 sub ProcessFLIRText($$$);
@@ -476,10 +476,10 @@ my %float8g = ( Format => 'float', PrintConv => 'sprintf("%.8g",$val)' );
     GROUPS => { 0 => 'APP1', 2 => 'Image' },
     PROCESS_PROC => \&ProcessMeasInfo,
     FORMAT => 'int16u',
-    VARS => { NO_ID => 1 },
+    VARS => { ID_FMT => 'none' },
     NOTES => q{
         Tags listed below are only for the first measurement tool, however multiple
-        measurements may be added, and information is extracted for all of them. 
+        measurements may be added, and information is extracted for all of them.
         Tags for subsequent measurements are generated as required with the prefixes
         "Meas2", "Meas3", etc.
     },
@@ -548,7 +548,7 @@ my %float8g = ( Format => 'float', PrintConv => 'sprintf("%.8g",$val)' );
 %Image::ExifTool::FLIR::TextInfo = (
     GROUPS => { 0 => 'APP1', 2 => 'Image' },
     PROCESS_PROC => \&ProcessFLIRText,
-    VARS => { NO_ID => 1 },
+    VARS => { ID_FMT => 'none' },
     Label0 => { },
     Value0 => { },
     Label1 => { },
@@ -564,7 +564,7 @@ my %float8g = ( Format => 'float', PrintConv => 'sprintf("%.8g",$val)' );
 %Image::ExifTool::FLIR::ParamInfo = (
     GROUPS => { 0 => 'APP1', 2 => 'Image' },
     PROCESS_PROC => \&ProcessFLIRText,
-    VARS => { NO_ID => 1 },
+    VARS => { ID_FMT => 'none' },
     Generated => {
         Name => 'DateTimeGenerated',
         Description => 'Date/Time Generated',
@@ -1468,7 +1468,7 @@ sub ProcessMeasInfo($$$)
 sub ProcessFLIR($$;$)
 {
     my ($et, $dirInfo, $tagTablePtr) = @_;
-    my $raf = $$dirInfo{RAF} || new File::RandomAccess($$dirInfo{DataPt});
+    my $raf = $$dirInfo{RAF} || File::RandomAccess->new($$dirInfo{DataPt});
     my $verbose = $et->Options('Verbose');
     my $out = $et->Options('TextOut');
     my $base = $raf->Tell();
@@ -1633,7 +1633,7 @@ Systems Inc. thermal image files (FFF, FPF and JPEG format).
 
 =head1 AUTHOR
 
-Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2025, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
