@@ -12,11 +12,11 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 %Image::ExifTool::Trailer::Vivo = (
     GROUPS => { 0 => 'Trailer', 1 => 'Vivo', 2 => 'Image' },
-    VARS => { NO_ID => 1 },
+    VARS => { ID_FMT => 'none' },
     NOTES => 'Information written in JPEG trailer by some Vivo phones.',
     # (don't know for sure what type of image this is, but it is in JPEG format)
     HDRImage => {
@@ -96,7 +96,7 @@ sub ProcessVivo($$)
         $len -= $start;
         $buff = substr($buff, $start);
     }
-    # set trailer position and length 
+    # set trailer position and length
     @$dirInfo{'DataPos','DirLen'} = ($pos, $len);
 
     # let ProcessTrailers copy or delete this trailer
@@ -271,7 +271,7 @@ sub ProcessGoogle($$)
             DataPos => $start + $pos,
             DirLen  => $$len[$i],
         });
-        $et->HandleTag($tagTable, $$tag[$i], \$buff, { DataPos => $start + $pos, DataPt => \$buff });
+        $et->HandleTag($tagTable, $$tag[$i], \$buff, DataPos => $start + $pos, DataPt => \$buff);
         # (haven't seen non-zero padding, but I assume this is how it works
         $pos += $$len[$i] + (($pad and $$pad[$i]) ? $$pad[$i] : 0);
     }
